@@ -74,7 +74,7 @@ class CidClient:
         """
         Gets the crafts available and the elements that it is composed of.
         """
-        return self._user_info["user"]["instances_v0_1"]
+        return self._user_info["user"]["trees"]
 
     def fetch_craft(self, craft_id):
         """
@@ -93,13 +93,13 @@ class CidClient:
             raise ValueError("Provided craft id could not be found")
 
         # Pull down all the crates associated with the craft
-        # TODO might want to keep these separated? or at a minimum store a mapping from node guid to crate guid that it belongs to
+        # TODO might want to keep these separated? or at a minimum store a mapping from node id to crate id that it belongs to
         aggregate_crate = []
-        for crate in craft["instance_nodes"]:
+        for crate in craft["crate_ids"]:
             aggregate_crate += self._fetch_instance_crate(crate)["payload"]["crates"]
 
         # Pull down and create the tree associated with the craft
-        the_tree = self._fetch_instance_tree(craft["tree"])
+        the_tree = self._fetch_instance_tree(craft["frame_id"])
 
         return Craft(craft["name"], craft["id"], aggregate_crate, the_tree,
                      {"component_resync_query": self._component_resync_query,
@@ -121,35 +121,35 @@ class CidClient:
     #
     # Resync stuff
     #
-    def _component_resync_query(self, guid, detailed_nodes_id):
+    def _component_resync_query(self, id, crate_id):
         """
         :param payload: The payload to attach while requesting
         """
         return self._smart_post("/v1/instance/node/resync/query", payload={
-            "guid": guid,
-            "detailed_nodes_id": detailed_nodes_id
+            "id": id,
+            "crate_id": crate_id
         })
 
-    def _component_resync_execute(self, guid, detailed_nodes_id):
+    def _component_resync_execute(self, id, crate_id):
         """
         :param payload: The payload to attach while requesting
         """
         return self._smart_post("/v1/instance/node/resync/execute", payload={
-            "guid": guid,
-            "detailed_nodes_id": detailed_nodes_id
+            "id": id,
+            "crate_id": crate_id
         })
 
     #
     # Attribute stuff
     #
     def _component_attribute_edit(self,
-                                  guid,
+                                  id,
                                   attribute_name,
                                   attribute_id,
                                   value,
                                   traits,
                                   aux,
-                                  detailed_nodes_id):
+                                  crate_id):
         """
         :param payload: The payload to attach while requesting
         """
@@ -159,23 +159,23 @@ class CidClient:
             traits[OVERRIDDEN_KEY] = True
 
         return self._smart_post("/v1/instance/node/attribute/edit", payload={
-            "guid": guid,
+            "id": id,
             "name": attribute_name,
             "attribute_id": attribute_id,
             "value": value,
             "traits": traits,
             "aux": aux,
-            "detailed_nodes_id": detailed_nodes_id
+            "crate_id": crate_id
         })
 
-    def _component_attribute_remove(self, guid, attribute_id, detailed_nodes_id):
+    def _component_attribute_remove(self, id, attribute_id, crate_id):
         """
         :param payload: The payload to attach while requesting
         """
         return self._smart_post("/v1/instance/node/attribute/remove", payload={
-            "guid": guid,
+            "id": id,
             "attribute_id": attribute_id,
-            "detailed_nodes_id": detailed_nodes_id
+            "crate_id": crate_id
         })
 
     # ##############################################################################
@@ -203,8 +203,8 @@ class CidClient:
 
     def _fetch_instance_crate(self, crate_id):
         # TODO this api is named funy}
-        return self._smart_post("/v1/instance/nodes", payload={"detailed_nodes_collection": [crate_id], })
+        return self._smart_post("/v1/instance/nodes", payload={"crate_ids": [crate_id], })
 
-    def _fetch_instance_tree(self, tree_id):
+    def _fetch_instance_tree(self, farme_id):
         # TODO this api is named funy}
-        return self._smart_post("/v1/instance/tree", payload={"tree_id": tree_id, })
+        return self._smart_post("/v1/tree/frame/query", payload={"frame_id": frame_id, })
