@@ -17,9 +17,9 @@ class Component(object):
 
     def __init__(self, raw_component, network_callbacks):
         self.name = raw_component["name"]
-        self.id = raw_component["guid"]
+        self.id = raw_component["id"]
         self.attributes = raw_component["attributes"]
-        self.generic_component_ids = raw_component["base_node_guids"]
+        self.generic_component_ids = raw_component["template_ids"]
         self.crate_id = raw_component["crate_id"]
 
         self._network_callbacks = network_callbacks
